@@ -11,6 +11,7 @@ from django.conf import settings
 from django.core.mail import EmailMultiAlternatives
 from django.core.urlresolvers import reverse
 from django.template.loader import render_to_string
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 from sentry.models import User, UserOption
 from sentry.plugins import register
@@ -179,10 +180,10 @@ class MailPlugin(NotificationPlugin):
 
         interface_list = []
         for interface in event.interfaces.itervalues():
-            body = interface.to_string(event)
+            body = interface.to_email_html(event)
             if not body:
                 continue
-            interface_list.append((interface.get_title(), body))
+            interface_list.append((interface.get_title(), mark_safe(body)))
 
         subject = '[%s] %s: %s' % (
             project.name.encode('utf-8'),
